@@ -52,7 +52,7 @@ AVAILABILITY_ZONES = [
     'us-east-1a', 'us-east-1b', 'us-east-1c', 'us-east-1d', 'us-east-1e', 'us-east-1f',
     'us-east-2a', 'us-east-2b', 'us-east-2c',
     'us-west-1a', 'us-west-1b', 'us-west-1c',
-    'us-west-2a', 'us-west-2b', 'us-west-2c',
+    'us-west-2a', 'us-west-2b', 'us-west-2c', 'us-west-2d',
     'ca-central-1a', 'ca-central-1b',
     'sa-east-1a', 'sa-east-1b', 'sa-east-1c',
     'eu-west-1a', 'eu-west-1b', 'eu-west-1c',
@@ -61,11 +61,11 @@ AVAILABILITY_ZONES = [
     'eu-central-1a', 'eu-central-1b', 'eu-central-1c',
     'eu-central-2a', 'eu-central-2b', 'eu-central-2c',
     'ap-northeast-1a', 'ap-northeast-1b', 'ap-northeast-1c', 'ap-northeast-1d',
-    'ap-northeast-2a', 'ap-northeast-2b',
+    'ap-northeast-2a', 'ap-northeast-2b', 'ap-northeast-2c',
     'ap-northeast-3a',
     'ap-southeast-1a', 'ap-southeast-1b', 'ap-southeast-1c',
     'ap-southeast-2a', 'ap-southeast-2b', 'ap-southeast-2c',
-    'ap-south-1a', 'ap-south-1b',
+    'ap-south-1a', 'ap-south-1b', 'ap-south-1c',
     'cn-north-1a', 'cn-north-1b',
     'eu-west-3a', 'eu-west-3b', 'eu-west-3c',
     'ap-northeast-3a',
